/**
 * 出現時機：第一次訪問網站或超過網站留存Cookies使用期限，希望全網域統一請用戶簽署同意一次就好。
 * 隱私權政策連結：https://www.cnyes.com/cnyes_about/cnyes_sos04.html
 * 接受按鈕：表示同意＆關掉notice
 * 叉叉按鈕：表示當次session不同意=下次再問一次＆關掉notice
 * 不要蓋住置底或蓋板廣告，可以蓋住back to top & floating button
 */
import React from 'react';
import classNames from 'classnames/bind';
import PropTypes from 'prop-types';
import styles from './CookieConsentBar.scss';
import Cookies from '../../assets/cookies.svg';

const cx = classNames.bind(styles);

const YEAR_100 = 1000 * 60 * 60 * 24 * 365 * 100;
const ALLOWED_DOMAINS = ['localhost', '.stage.cnyes.cool', '.beta.cnyes.cool', '.cnyes.com'];

export default class CookieConsentBar extends React.PureComponent {
  static propTypes = {
    customStyle: PropTypes.PropTypes.shape({}),
  };

  static defaultProps = {
    customStyle: {},
  };

  constructor(props) {
    super(props);

    this.state = {
      isShow: false,
    };
    this.isClient = typeof window !== 'undefined';
    this.farFuture = new Date(new Date().getTime() + YEAR_100); // 設定100年，持續永久
  }

  componentWillMount() {
    if (this.isClient && !document.cookie.includes('consentCookie')) {
      this.setState({ isShow: true });
    }
  }

  handleClickClose = () => {
    this.setState({ isShow: false });
  };

  handleClickConcent = () => {
    ALLOWED_DOMAINS.forEach(domain => {
      if (this.isClient && location.href.includes(domain)) {
        // localhost 供本地測試用，需不設網域。
        const domainStr = domain === 'localhost' ? '' : `domain=${domain};`;

        document.cookie = `consentCookie=true; ${domainStr} expires=${this.farFuture}`;
      }
    });
    this.setState({ isShow: false });
  };

  render() {
    const { isShow } = this.state;
    const { customStyle } = this.props;

    if (!isShow) return null;

    return (
      <div className={cx('cookie-bar-container')} style={customStyle}>
        <div className={cx('cookie-bar')}>
          <img src={Cookies} alt="cookies" />
          <p>
            為優化網站服務，鉅亨網使用Cookie來改善使用者體驗。當您繼續使用本網站即表示您同意Cookies政策與<a
              href="https://www.cnyes.com/cnyes_about/cnyes_sos04.html"
              target="_blank"
              rel="noopener noreferrer"
            >
              隱私權政策
            </a>。
          </p>
          <button className={cx('consent')} onClick={this.handleClickConcent}>
            繼續使用
          </button>
          <button className={cx('close')} onClick={this.handleClickClose} />
        </div>
      </div>
    );
  }
}
