import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import styles from './Crypto.scss';
import gaDataset from '../../utils/gaDataset';
import { COMPANIGN_URL } from './Crypto';

const cx = classNames.bind(styles);

export const CARD_TYPE = {
  LEFT: 'left',
  TOP: 'top',
  BOTTOM: 'bottom',
};

const renderCompanyLogo = logo => {
  return <img src={logo} alt="" />;
};

const renderSymbolIcon = symbol => {
  return <img src={`${COMPANIGN_URL}/assets/crypto-${symbol}.svg`} alt="" />;
};

const selectcardContentTheme = type => {
  switch (type) {
    case CARD_TYPE.TOP:
      return 'card-content--top';
    case CARD_TYPE.LEFT:
      return 'card-content--left';
    case CARD_TYPE.BOTTOM:
      return 'card-content--bottom';
    default:
      return 'card-content--top';
  }
};

const selectcardTheme = type => {
  switch (type) {
    case CARD_TYPE.TOP:
      return 'card-top';
    case CARD_TYPE.BOTTOM:
      return 'card-bottom';
    default:
      return 'card';
  }
};

const Card = ({ data, type }) => {
  const { logo, title, link, gaEvent = null, price, description, subdescription, performance, cardTitle } = data;
  const cardContentTheme = selectcardContentTheme(type);
  const cardTheme = selectcardTheme(type);

  const renderTable = () => (
    <table>
      <thead>
        <tr>{performance && performance.headers.map(header => <th key={header}>{header}</th>)}</tr>
      </thead>
      <tbody>
        {performance &&
          performance.rows.map(({ symbol, value, day, tag }, idx) => {
            return (
              <tr key={`row-${idx.toString()}`}>
                <td>
                  {renderSymbolIcon(symbol.toLowerCase())}
                  <span>{symbol}</span>
                  {tag && <span className={cx('symbol-tag')}>{tag}</span>}
                </td>
                <td>{value}</td>
                <td>{day}</td>
              </tr>
            );
          })}
      </tbody>
    </table>
  );

  const handleClick = () => {
    if (typeof window !== 'undefined') {
      window.parent.postMessage(gaEvent, '*');
      window.open(link, '_blank');
    }
  };

  const renderCardTitle = () => {
    return (
      <div className={cx('group-title')}>
        <span>{cardTitle}</span>
      </div>
    );
  };

  const BottomCard = () => (
    <div className={cx('card', cardTheme)} {...gaDataset(gaEvent)} onClick={handleClick}>
      {renderCardTitle()}
      <div className={cx('card-header')}>
        {renderCompanyLogo(logo)}
        <span className={cx('card-header--title')}>{title}</span>
      </div>
      <div className={cx('card-content', cardContentTheme)}>{renderTable()}</div>
    </div>
  );

  const TopCard = () => {
    return (
      <div className={cx('card', cardTheme)} {...gaDataset(gaEvent)} onClick={handleClick}>
        {renderCardTitle()}
        <img src={logo} className={cx('card-logo')} alt="icon" />
        <h3 dangerouslySetInnerHTML={{ __html: description }} />
        <img src={price} className={cx('card-price')} alt="price" />
        <span className="description">{subdescription}</span>
      </div>
    );
  };

  return type === CARD_TYPE.TOP ? <TopCard /> : <BottomCard />;
};

Card.propTypes = {
  data: {
    id: PropTypes.oneOf('pionex', 'binance', 'ace', 'bincentive', 'pokket'),
    title: PropTypes.string,
    link: PropTypes.string,
    gaEvent: PropTypes.object,
    description: PropTypes.oneOfType(PropTypes.string, null),
    features: {
      title: PropTypes.string,
      subTitle: PropTypes.string,
      description: PropTypes.string,
    },
    performance: {
      headers: PropTypes.array,
      rows: PropTypes.arrayOf({
        symbol: PropTypes.string,
        value: PropTypes.string,
        day: PropTypes.string,
      }),
    },
  },
  type: PropTypes.oneOf([CARD_TYPE.TOP, CARD_TYPE.BOTTOM, CARD_TYPE.LEFT]),
};
Card.defaultProps = {
  data: {},
  type: 'small',
};

export default Card;
