import React from 'react';
import classNames from 'classnames/bind';
import PropTypes from 'prop-types';
import styles from './Crypto.scss';
import Card, { CARD_TYPE } from './Card';
import gaDataset from '../../utils/gaDataset';
import config from './config.json';

const cx = classNames.bind(styles);

export const COMPANIGN_URL = 'https://campaign.cnyes.com/topics/cryptoV2';

const Crypto = ({ isShowHeader }) => {
  const { header, topGroup, bottomGroup } = config;
  const { title, readmore, gaEvent } = header;

  const handleClick = clickGaEvent => {
    if (typeof window !== 'undefined') {
      window.parent.postMessage(clickGaEvent, '*');
    }
  };

  const renderHeader = (
    <div className={cx('crypto-header')}>
      <div className={cx('crypto-header--title')}>
        <a
          href={title.link}
          rel="noopener noreferrer"
          {...gaDataset(gaEvent.title)}
          target="_blank"
          onClick={() => handleClick(gaEvent.title)}
        >
          {title.name}
        </a>
      </div>
      <div className={cx('crypto-readmore')}>
        <span className={cx('crypto-readmore--updatetime')}>更新日期： {header.updatetime}</span>
        <a
          href={readmore.link}
          rel="noopener noreferrer"
          target="_blank"
          {...gaDataset(gaEvent.readmore)}
          onClick={() => handleClick(gaEvent.readmore)}
        >
          看更多
          <img alt="arrow icon" src={`${COMPANIGN_URL}/assets/icon-arrow.svg`} />
        </a>
      </div>
    </div>
  );

  return (
    <div className={cx('crypto')}>
      {isShowHeader && renderHeader}

      <div className={cx('crypto-content')}>
        <div className={cx('crypto-content--top')}>
          {topGroup.map(company => <Card data={company} type={CARD_TYPE.TOP} key={company.id} />)}
        </div>
        <div className={cx('crypto-content--bottom')}>
          {bottomGroup.map(company => <Card data={company} type={CARD_TYPE.BOTTOM} key={company.id} />)}
        </div>
      </div>
    </div>
  );
};

Crypto.propTypes = {
  isShowHeader: PropTypes.bool,
};

Crypto.defaultProps = {
  isShowHeader: false,
};

export default Crypto;
