import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import { THEME } from './Dialog';
import styles from './Dialog.scss';

const cx = classNames.bind(styles);

const DialogButton = ({ children, onClick, active, theme }) => {
  const themeStyle = theme === THEME.NORMAL ? 'theme-normal' : 'theme-anue';

  return (
    <button type="button" className={cx('dialog__button', themeStyle, { active })} onClick={onClick}>
      {children}
    </button>
  );
};

DialogButton.propTypes = {
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]).isRequired,
  onClick: PropTypes.func,
  theme: PropTypes.string.isRequired,
  active: PropTypes.bool,
};

DialogButton.defaultProps = {
  onClick: () => {},
  active: false,
};

export default DialogButton;
