/* eslint-disable global-require */
/* eslint-disable import/no-dynamic-require */
/* eslint-disable no-unused-expressions */
import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import throttle from 'lodash.throttle';
import gaDataset from '../../utils/gaDataset';
import styles from './FloatingCard.scss';

const cx = classnames.bind(styles);

class FloatingCard extends React.Component {
  static propTypes = {
    href: PropTypes.string,
    image: PropTypes.string.required,
    width: PropTypes.number,
    height: PropTypes.number,
    description: PropTypes.string,
    rotatingOffset: PropTypes.number,
    wrapperStyle: PropTypes.shape({}),
    gaEvent: PropTypes.shape({
      dataPrefix: PropTypes.arrayOf(PropTypes.string),
      category: PropTypes.string,
      action: PropTypes.string,
      label: PropTypes.string,
    }),
  };

  static defaultProps = {
    href: '',
    image: '',
    description: '',
    rotatingOffset: 30,
    width: 100,
    height: 136,
    gaEvent: {
      dataPrefix: ['global'],
      category: 'FloatingBTN',
      action: 'Click',
      label: '',
    },
    wrapperStyle: {},
  };

  constructor(props) {
    super(props);

    const {
      gaEvent: { dataPrefix, category, action, label },
    } = props;

    this.state = {
      showScrollTop: false,
      isRotate: false,
    };
    this.gaEvent = {
      ...gaDataset({
        dataPrefix: dataPrefix.map(dp => `data-${dp}-ga`),
        category,
        action,
        label,
      }),
    };

    this.isGif = false;
    this.isScrolling = null;
    this.start = null;
    this.end = null;
    this.distance = null;
  }

  componentDidMount() {
    if (typeof window !== 'undefined') {
      window.addEventListener('scroll', this.handleRotating, false);
    }
  }

  componentWillUnmount() {
    if (typeof window !== 'undefined') {
      window.removeEventListener('scroll', this.handleRotating, false);
    }
  }

  /**
   * 這個元件最主要的動畫效果是，當往下滾動時，到達一定移動距離(靈敏度)後即啟動動畫效果
   * 反之，如果往上回捲，一樣需要到達一定移動距離後，才會還原動畫
   *
   * 滾動距離偵測:
   * https://gomakethings.com/detecting-scroll-distances-with-vanilla-js/
   */
  handleRotating = throttle(() => {
    const { rotatingOffset } = this.props;

    // Set starting position
    if (!this.start) {
      this.start = window.pageYOffset;
    }

    // Clear our timeout throughout the scroll
    window.clearTimeout(this.isScrolling);

    // Set a timeout to run after scrolling ends
    this.isScrolling = setTimeout(() => {
      // Calculate distance
      this.end = window.pageYOffset;
      this.distance = this.end - this.start;

      // Run the callback
      if (Math.abs(this.distance) > rotatingOffset) {
        // 往下捲
        if (this.distance > 0) {
          !this.state.isRotate && this.setState({ isRotate: true });
          // 往上捲
        } else {
          this.state.isRotate && this.setState({ isRotate: false });
        }
      }

      // Reset calculations
      this.start = null;
      this.end = null;
      this.distance = null;
    }, 66);
  }, 50);

  render() {
    const { href, image, description, width, height, wrapperStyle } = this.props;
    const { isRotate } = this.state;

    return (
      <a
        className={cx('wrapper')}
        style={{ width, height, ...wrapperStyle }}
        href={href}
        target="_blank"
        rel="noreferrer noopener"
        title={description}
        {...this.gaEvent}
      >
        <img className={cx({ rotate: isRotate })} src={image} alt={description || ''} />
      </a>
    );
  }
}

export default FloatingCard;
