/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import * as knobs from '@storybook/addon-knobs/react';
import ScrollToTop from '../../ScrollToTop/ScrollToTop';
import FloatingCard from '../FloatingCard';
import defaultNotes from './FloatingCard.md';
import FloatingImage from '../AD_fixed.png';

const stories = storiesOf('FloatingCard', module);

stories.addDecorator(knobs.withKnobs);
stories.addDecorator(story => (
  <div>
    <div style={{ width: '100%', height: '1000px', padding: '40px 200px' }}>
      <div id={'div_1'} style={{ paddingTop: '30px' }}>
        A區塊
      </div>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <div style={{ width: '100%', height: '300px' }} />
      <div id={'div_2'} style={{ paddingTop: '30px' }}>
        B區塊
      </div>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <div style={{ width: '100%', height: '400px' }} />
      <div id={'div_3'} style={{ paddingTop: '30px' }}>
        C區塊
      </div>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <div style={{ width: '100%', height: '500px' }} />
      <div id={'div_4'} style={{ paddingTop: '30px' }}>
        D區塊
      </div>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
      <p>long content here...</p>
    </div>
    {story()}
  </div>
));

stories.add(
  '預設',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = <FloatingCard image={FloatingImage} href="https://www.cnyes.com" />;

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '懸浮圖片靠左對齊',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = <FloatingCard image={FloatingImage} href="https://www.cnyes.com" />;

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="left"
        />
      );
    })
  )
);

stories.add(
  '懸浮圖片置中對齊',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = <FloatingCard image={FloatingImage} href="https://www.cnyes.com" />;

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="center"
        />
      );
    })
  )
);

stories.add(
  '懸浮圖片靠右對齊',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = <FloatingCard image={FloatingImage} href="https://www.cnyes.com" />;

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '減緩靈敏度',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = <FloatingCard image={FloatingImage} href="https://www.cnyes.com" rotatingOffset={100} />;

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '變更圖片大小',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = (
        <FloatingCard width={150} height={200} image={FloatingImage} href="https://www.cnyes.com" />
      );

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '換張圖片',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = (
        <FloatingCard
          width={100}
          height={40}
          image="https://sfiles.cnyes.cool/fe-common/e6e1fc45/ac25a5abb8fcbdfddb46fa4e9bca6b06.svg"
          href="https://www.cnyes.com"
        />
      );

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '載入 Gif 圖檔',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = (
        <FloatingCard
          width={256}
          height={256}
          image="https://i.stack.imgur.com/ATB3o.gif"
          href="https://www.cnyes.com"
        />
      );

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '自訂樣式',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = (
        <FloatingCard
          image={FloatingImage}
          href="https://www.cnyes.com"
          wrapperStyle={{ marginBottom: '16px', border: '1px solid' }}
        />
      );

      return (
        <ScrollToTop
          showOffset={100}
          hasFooter={false}
          showOnMobile={false}
          stickyComponent={stickyComponent}
          stickyAlign="right"
        />
      );
    })
  )
);

stories.add(
  '設定 GA',
  withNotes(defaultNotes)(
    withInfo()(() => {
      const stickyComponent = (
        <FloatingCard
          href="https://www.cnyes.com"
          gaEvent={{
            dataPrefix: ['global'],
            category: 'FloatingBTN',
            action: 'Click',
            label: '美股勝投王',
          }}
        />
      );

      return <ScrollToTop showOffset={100} hasFooter={false} showOnMobile={false} stickyComponent={stickyComponent} />;
    })
  )
);
