/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import SvgChart from '../SvgChart';
import notes from './SvgChart.md';
import dataTw from './mockTw';
import dataJpIndex from './mockJpIndex';

storiesOf('SvgChartV2', module)
  .addDecorator(story => <div style={{ padding: '1rem' }}>{story()}</div>)
  .add(
    'single session',
    withInfo()(
      withNotes(notes)(() => {
        const t = [...dataTw.t].reverse();
        const c = [...dataTw.c].reverse();
        const session = dataTw.session;

        return (
          <SvgChart
            updateKey="updateKey"
            height={102}
            width={172}
            padding={0}
            t={t}
            c={c}
            base={255}
            session={session}
            highlightLastPoint
          />
        );
      })
    )
  )
  .add(
    'double session',
    withInfo()(
      withNotes(notes)(() => {
        const t = [...dataJpIndex.t].reverse();
        const c = [...dataJpIndex.c].reverse();
        const session = dataJpIndex.session;

        return (
          <SvgChart
            updateKey="updateKey"
            height={102}
            width={172}
            padding={0}
            t={t}
            c={c}
            base={18000}
            session={session}
          />
        );
      })
    )
  )
  .add(
    'product list',
    withInfo()(
      withNotes(notes)(() => {
        const data = [
          {
            t: [...dataTw.t].reverse(),
            c: [...dataTw.c].reverse(),
            session: dataTw.session,
            base: 255,
            name: '台灣加權指數',
          },
          {
            t: [...dataJpIndex.t].reverse(),
            c: [...dataJpIndex.c].reverse(),
            session: dataJpIndex.session,
            base: 18000,
            name: '日經指數',
          },
        ];

        return (
          <div style={{ display: 'flex', flexDirection: 'column' }}>
            {Array(50)
              .fill(null)
              .map((_, index) => {
                const { t, c, session, base, name } = data[index % 2];
                const bgColor = index % 2 === 0 ? 'white' : '#f1f1f1';

                return (
                  <div
                    // eslint-disable-next-line react/no-array-index-key
                    key={index}
                    style={{
                      display: 'flex',
                      flexDirection: 'row',
                      justifyContent: 'flex-start',
                      alignItems: 'center',
                      background: bgColor,
                      padding: '20px 16px',
                    }}
                  >
                    <div style={{ width: '200px' }}>{name}</div>
                    <SvgChart
                      updateKey="updateKey"
                      height={40}
                      width={80}
                      padding={0}
                      marginTop={0}
                      t={t}
                      c={c}
                      base={base}
                      session={session}
                      shouldPreventHoverEvent
                    />
                  </div>
                );
              })}
          </div>
        );
      })
    )
  );
